/*
 * =====================================================================================
 *
 *       Filename:  CSCRenderPlugin.h
 *
 *    Description:  CSC Histogram Rendering Plugin
 *
 *        Version:  1.0
 *        Created:  05/06/2008 03:50:48 PM
 *       Revision:  none
 *       Compiler:  gcc
 *
 *         Author:  Valdas Rapsevicius (VR), Valdas.Rapsevicius@cern.ch
 *        Company:  CERN, CH
 *
 * =====================================================================================
 */

#ifndef CSCRenderPlugin_H
#define CSCRenderPlugin_H

#include "VisMonitoring/DQMServer/interface/DQMRenderPlugin.h"
#include "VisMonitoring/DQMServer/interface/DQMRenderPluginDB.h"
#include "CSCDetector.h"

#include <math.h>
#include <string>
#include <bitset>
#include <TH1.h>
#include <TH2.h>
#include <TBox.h>
#include <TText.h>
#include <TPRegexp.h>
#include <TStyle.h>
#include <TCanvas.h>

#define REMATCH(pat, str)              (TPRegexp(pat).MatchB(str))
#define REREPLACE(pat, str, rep)       { TString s(str); TPRegexp(pat).Substitute(s, rep); str = s; }

/**
 * @class ChamberMap
 * @brief Class that draws CSC Map diagram
 */
class ChamberMap {
  public:
    ChamberMap();
    ~ChamberMap();
    void draw(TH2*& me) const;
    void drawStats(TH2*& me) const;
  private:
    void printLegendBox(unsigned int& number, const std::string title, const int color) const;
    const float Xmin_local_derived_from_ChamberID(const int side, const int station, const int ring, const int chamber) const;
    const float Xmax_local_derived_from_ChamberID(const int side, const int station, const int ring, const int chamber) const;
    const float Ymin_local_derived_from_ChamberID(const int side, const int station, const int ring, const int chamber) const;
    const float Ymax_local_derived_from_ChamberID(const int side, const int station, const int ring, const int chamber) const;
    const int N_ring(const int station) const;
    const int N_chamber(const int station, const int ring) const;
    TBox *bBlank;
};

/**
 * @class SummaryMap
 * @brief Class that draws CSC Summary Map diagram
 */
class SummaryMap {
  public:
    SummaryMap();
    ~SummaryMap();
    void drawDetector(TH2* me); 
    void drawStation(TH2* me, const int station);
  private:
    CSCDetector detector;
    TH2F *h1;
    TBox *bBlank;
    TBox *bEmptyMinus;
    TBox *bEmptyPlus;
};

/**
 * @class CSCRenderPlugin
 * @brief Actual render plugin for CSCs
 */
class CSCRenderPlugin : public DQMRenderPlugin {
  public:
    virtual bool applies( const DQMNet::CoreObject &o, const VisDQMImgInfo &i );
    virtual void preDraw( TCanvas *c, const DQMNet::CoreObject &o, const VisDQMImgInfo &i, VisDQMRenderInfo&  r);
    virtual void postDraw( TCanvas *c, const DQMNet::CoreObject &o, const VisDQMImgInfo &i );
   private:
    ChamberMap chamberMap;
    SummaryMap summaryMap;
};


#endif
